/**
 * Copyright 2023 Velocity Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

const { createKmsClient } = require('./aws-factory');

const initKmsClient = ({ awsRegion, awsEndpoint }) => {
  const kmsClient = createKmsClient({
    awsRegion,
    awsEndpoint,
  });

  const encrypt = async (keyId, plaintext) => {
    const params = {
      KeyId: keyId,
      Plaintext: plaintext,
    };

    return kmsClient.encrypt(params).promise();
  };

  const decrypt = async (ciphertextBlob) => {
    const params = {
      CiphertextBlob: ciphertextBlob,
    };

    return kmsClient.decrypt(params).promise();
  };

  return {
    encrypt,
    decrypt,
  };
};

module.exports = {
  initKmsClient,
};
